# Changelog

## 0.3.3 - 2019-09-24

* Added jsonschema dependency to packages

## 0.3.2 - 2019-09-22

* Use choria plugin configuration directory from environment if set
  [mcorpc-agent-provider#121](https://github.com/choria-io/mcorpc-agent-provider/issues/121)
* Fix inclusion of schemas within package

## 0.3.1 - 2019-09-19

* Strip tests from packages

## 0.3 - 2019-09-19

* Fix schemas packaging error

## 0.2 - 2019-09-19

* Updated schemas and protocol names in line with Choria changes
* Vendor in a copy of the protocol message schemas

## 0.1 - 2019-09-18

* Initial release

